@@ -605,9 +605,13 @@ YAHOO.crud.decorateRemoveCells = function() {
 // method to generate a query string for the DataSource.  
 // Also used as the state indicator for the History Manager
 YAHOO.crud.generateStateString = function (start,key,dir,psize) {
+    var sort_param = 'cxc-sort';
+    if (key.match(/ (ASC|DESC)/i)) {
+        sort_param = 'cxc-order';
+    }
     return  "&cxc-page_size="  +   psize   + 
             "&cxc-offset="     +   start   +
-            "&cxc-sort="       +   key     +
+            "&" + sort_param + "=" +   key +
             "&cxc-dir="        +   dir;
 };
 
